Color32

Struct Color32 

pub struct Color32(/* private fields */);
This format is used for space-efficient color representation (32 bits).

Instead of manipulating this directly it is often better to first convert it to either Rgba or Hsva.

Internally this uses 0-255 gamma space sRGBA color with premultiplied alpha. Alpha channel is in linear space.

Implementations

Source

impl Color32

pub const TRANSPARENT: Color32

pub const BLACK: Color32

pub const DARK_GRAY: Color32

pub const GRAY: Color32

pub const LIGHT_GRAY: Color32

pub const WHITE: Color32

pub const BROWN: Color32

pub const DARK_RED: Color32

pub const RED: Color32

pub const LIGHT_RED: Color32

pub const YELLOW: Color32

pub const LIGHT_YELLOW: Color32

pub const KHAKI: Color32

pub const DARK_GREEN: Color32

pub const GREEN: Color32

pub const LIGHT_GREEN: Color32

pub const DARK_BLUE: Color32

pub const BLUE: Color32

pub const LIGHT_BLUE: Color32

pub const GOLD: Color32

pub const DEBUG_COLOR: Color32

pub const TEMPORARY_COLOR: Color32

An ugly color that is planned to be replaced before making it to the screen.

pub const fn from_rgb(r: u8, g: u8, b: u8) -> Color32

pub const fn from_rgb_additive(r: u8, g: u8, b: u8) -> Color32

pub const fn from_rgba_premultiplied(r: u8, g: u8, b: u8, a: u8) -> Color32

From sRGBA with premultiplied alpha.

pub fn from_rgba_unmultiplied(r: u8, g: u8, b: u8, a: u8) -> Color32

From sRGBA WITHOUT premultiplied alpha.

pub const fn from_gray(l: u8) -> Color32

pub const fn from_black_alpha(a: u8) -> Color32

pub fn from_white_alpha(a: u8) -> Color32

pub const fn from_additive_luminance(l: u8) -> Color32

pub const fn is_opaque(&self) -> bool

pub const fn r(&self) -> u8

pub const fn g(&self) -> u8

pub const fn b(&self) -> u8

pub const fn a(&self) -> u8

pub fn to_opaque(self) -> Color32

Returns an opaque version of self

pub const fn additive(self) -> Color32

Returns an additive version of self

pub const fn to_array(&self) -> [u8; 4]

Premultiplied RGBA

pub const fn to_tuple(&self) -> (u8, u8, u8, u8)

Premultiplied RGBA

pub fn to_srgba_unmultiplied(&self) -> [u8; 4]

pub fn linear_multiply(self, factor: f32) -> Color32

Multiply with 0.5 to make color half as opaque.