pub struct FontDefinitions {
pub font_data: BTreeMap<String, FontData>,
pub families: BTreeMap<FontFamily, Vec<String>>,
}Expand description
Describes the font data and the sizes to use.
Often you would start with FontDefinitions::default() and then add/change the contents.
This is how you install your own custom fonts:
let mut fonts = FontDefinitions::default();
// Install my own font (maybe supporting non-latin characters):
fonts.font_data.insert("my_font".to_owned(),
FontData::from_static(include_bytes!("../../fonts/Ubuntu-Light.ttf"))); // .ttf and .otf supported
// Put my font first (highest priority):
fonts.families.get_mut(&FontFamily::Proportional).unwrap()
.insert(0, "my_font".to_owned());
// Put my font as last fallback for monospace:
fonts.families.get_mut(&FontFamily::Monospace).unwrap()
.push("my_font".to_owned());
egui_ctx.set_fonts(fonts);Fields
font_data: BTreeMap<String, FontData>List of font names and their definitions.
epaint has built-in-default for these, but you can override them if you like.
families: BTreeMap<FontFamily, Vec<String>>Which fonts (names) to use for each FontFamily.
The list should be a list of keys into Self::font_data.
When looking for a character glyph epaint will start with
the first font and then move to the second, and so on.
So the first font is the primary, and then comes a list of fallbacks in order of priority.
Implementations
Sourceimpl FontDefinitions
impl FontDefinitions
Sourcepub fn empty() -> FontDefinitions
pub fn empty() -> FontDefinitions
No fonts.