pub struct CCursor {
pub index: usize,
pub prefer_next_row: bool,
}Expand description
Character cursor
Fields
index: usizeCharacter offset (NOT byte offset!).
prefer_next_row: boolIf this cursors sits right at the border of a wrapped row break (NOT paragraph break) do we prefer the next row? This is almost always what you want, except for when explicitly clicking the end of a row or pressing the end key.
Implementations