PlotImage

Struct PlotImage 

pub struct PlotImage { /* private fields */ }
An image in the plot.

Implementations

Source

impl PlotImage

pub fn new( texture_id: impl Into<TextureId>, center_position: PlotPoint, size: impl Into<Vec2>, ) -> PlotImage

Create a new image with position and size in plot coordinates.

pub fn highlight(self, highlight: bool) -> PlotImage

Highlight this image in the plot.

pub fn uv(self, uv: impl Into<Rect>) -> PlotImage

Select UV range. Default is (0,0) in top-left, (1,1) bottom right.

pub fn bg_fill(self, bg_fill: impl Into<Color32>) -> PlotImage

A solid color to put behind the image. Useful for transparent images.

pub fn tint(self, tint: impl Into<Color32>) -> PlotImage

Multiply image color with this. Default is WHITE (no tint).

pub fn name(self, name: impl ToString) -> PlotImage

Name of this image.

This name will show up in the plot legend, if legends are turned on.

Multiple plot items may share the same name, in which case they will also share an entry in the legend.