Module mutex

Module mutex 

Helper module that wraps some Mutex types with different implementations.

Structs

Mutex
Provides interior mutability.
MutexGuard
The lock you get from Mutex.
RwLock
Provides interior mutability.

Type Aliases

RwLockReadGuard
An RAII read lock guard returned by RwLockReadGuard::map, which can point to a subfield of the protected data.
RwLockWriteGuard
An RAII write lock guard returned by RwLockWriteGuard::map, which can point to a subfield of the protected data.